==> knative-model-4.12.0-sources.jar: annotations/io/fabric8/knative/serving/v1beta1/ServiceListBuilder.java <==
package io.fabric8.knative.serving.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ServiceListBuilder extends io.fabric8.knative.serving.v1beta1.ServiceListFluentImpl<io.fabric8.knative.serving.v1beta1.ServiceListBuilder> implements VisitableBuilder<io.fabric8.knative.serving.v1beta1.ServiceList,io.fabric8.knative.serving.v1beta1.ServiceListBuilder> {

    io.fabric8.knative.serving.v1beta1.ServiceListFluent<?> fluent;
    Boolean validationEnabled;

    public ServiceListBuilder() { 
        this(true);
    }


    public ServiceListBuilder(Boolean validationEnabled) { 
        this(new ServiceList(), validationEnabled);
    }


    public ServiceListBuilder(io.fabric8.knative.serving.v1beta1.ServiceListFluent<?> fluent) { 
        this(fluent, true);
    }


    public ServiceListBuilder(io.fabric8.knative.serving.v1beta1.ServiceListFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new ServiceList(), validationEnabled);
    }


    public ServiceListBuilder(io.fabric8.knative.serving.v1beta1.ServiceListFluent<?> fluent,io.fabric8.knative.serving.v1beta1.ServiceList instance) { 
        this(fluent, instance, true);
    }


    public ServiceListBuilder(io.fabric8.knative.serving.v1beta1.ServiceListFluent<?> fluent,io.fabric8.knative.serving.v1beta1.ServiceList instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withItems(instance.getItems()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }


    public ServiceListBuilder(io.fabric8.knative.serving.v1beta1.ServiceList instance) { 
        this(instance,true);
    }


    public ServiceListBuilder(io.fabric8.knative.serving.v1beta1.ServiceList instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }


    public io.fabric8.knative.serving.v1beta1.ServiceList build() {
        ServiceList buildable = new ServiceList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ServiceListBuilder that = (ServiceListBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.4.2-sources.jar: annotations/io/fabric8/knative/serving/v1beta1/ServiceListBuilder.java <==
package io.fabric8.knative.serving.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ServiceListBuilder extends io.fabric8.knative.serving.v1beta1.ServiceListFluentImpl<io.fabric8.knative.serving.v1beta1.ServiceListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.knative.serving.v1beta1.ServiceList,io.fabric8.knative.serving.v1beta1.ServiceListBuilder> {

    io.fabric8.knative.serving.v1beta1.ServiceListFluent<?> fluent;
    java.lang.Boolean validationEnabled;

    public ServiceListBuilder() {
        this(true);
    }

    public ServiceListBuilder(java.lang.Boolean validationEnabled) {
        this(new ServiceList(), validationEnabled);
    }

    public ServiceListBuilder(io.fabric8.knative.serving.v1beta1.ServiceListFluent<?> fluent) {
        this(fluent, true);
    }

    public ServiceListBuilder(io.fabric8.knative.serving.v1beta1.ServiceListFluent<?> fluent,java.lang.Boolean validationEnabled) {
        this(fluent, new ServiceList(), validationEnabled);
    }

    public ServiceListBuilder(io.fabric8.knative.serving.v1beta1.ServiceListFluent<?> fluent,io.fabric8.knative.serving.v1beta1.ServiceList instance) {
        this(fluent, instance, true);
    }

    public ServiceListBuilder(io.fabric8.knative.serving.v1beta1.ServiceListFluent<?> fluent,io.fabric8.knative.serving.v1beta1.ServiceList instance,java.lang.Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withItems(instance.getItems()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public ServiceListBuilder(io.fabric8.knative.serving.v1beta1.ServiceList instance) {
        this(instance,true);
    }

    public ServiceListBuilder(io.fabric8.knative.serving.v1beta1.ServiceList instance,java.lang.Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.serving.v1beta1.EditableServiceList build() {
        EditableServiceList buildable = new EditableServiceList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
        return buildable;
    }

    public boolean equals(java.lang.Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ServiceListBuilder that = (ServiceListBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
